{u_select.pas - FASTA_BLAST_Scan
 	Copyright (C) 1997-2011 Olivier Friard
        (annhyb @ gmail.com)

  This file is part of FASTA_BLAST_Scan.

FASTA_BLAST_Scan is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

FASTA_BLAST_Scan is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with FASTA_BLAST_Scan; see the file COPYING.TXT.  If not, write to
the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
}

unit u_select;

interface

uses
  SysUtils, Types, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls;

type
  TfrmSelect = class(TForm)
    Label1: TLabel;
    btnClose: TButton;
    edLength: TEdit;
    edHomol: TEdit;
    edCutoff: TEdit;
    lbLength: TLabel;
    lbHomology: TLabel;
    lbCutoff: TLabel;
    gbKeyword: TGroupBox;
    edMatch: TEdit;
    edNoMatch: TEdit;
    lbSelect: TLabel;
    lbUnselect: TLabel;
    procedure edLengthChange(Sender: TObject);
    procedure edLengthExit(Sender: TObject);
    procedure edLengthKeyPress(Sender: TObject; var Key: Char);
    procedure edHomolChange(Sender: TObject);
    procedure edHomolExit(Sender: TObject);
    procedure edHomolKeyPress(Sender: TObject; var Key: Char);
    procedure edCutoffChange(Sender: TObject);
    procedure edCutoffExit(Sender: TObject);
    procedure edCutoffKeyPress(Sender: TObject; var Key: Char);
    procedure edMatchKeyPress(Sender: TObject; var Key: Char);
    procedure btnCloseClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var frmSelect: TfrmSelect;

implementation

uses u_main;

{$R *.dfm}

procedure updatelength(l:integer);
var i:integer;
    s:shortstring;
begin
with frmMain do
    for i:=0 to lv.items.Count-1 do
        begin
        lv.items[i].checked:=false;
        if lv.items[i].subitems.count>=4 then
           s:=trim(lv.items[i].subitems.strings[4]);    //length
        if strtoint(s)>=l then
           lv.items[i].checked:=true;
        end;
frmSelect.edHomol.text:='';
frmSelect.edCutOff.text:='';
compte;
end;

procedure updateHomol(h:double);
var i:integer;
    s:shortstring;
begin
if (h<0) or (h>100) then
   begin
   showmessage('Homology value out of range (0-100)');
   exit;
   end;
with frmMain do
for i:=0 to lv.items.Count-1 do
    begin
    lv.items[i].checked:=false;
    if lv.items[i].subitems.count>=3 then
       s:=trim(lv.items[i].subitems.strings[3]);    //homol
    if strtofloat(s)>=h then
       lv.items[i].checked:=true;
    end;
frmSelect.edLength.text:='';
frmSelect.edCutOff.text:='';
compte;
end;

procedure updateCutOff(co:double);
var i:integer;
    len,homol:shortstring;
begin
if (co<0) or (co>1) then
   begin
   showmessage('Cut-off value out of range (0-1)');
   exit;
   end;
with frmMain do
for i:=0 to lv.items.Count-1 do
     begin
     lv.items[i].checked:=false; //dselection
     if lv.items[i].subitems.count>=4 then
        begin
        homol:=trim(lv.items[i].subitems.strings[3]);    //homol  4
//     if lv.items[i].subitems.count>=4 then
        len:=trim(lv.items[i].subitems.strings[4]);    //length   5
        end;
     if strtofloat(homol)*strtoint(len)/ls/100 >= co then
        lv.items[i].checked:=true;
     end;
frmSelect.edHomol.text:='';
frmSelect.edLength.text:='';
compte;
end;



procedure TfrmSelect.edLengthChange(Sender: TObject);
begin
if edlength.Focused then
   begin
   edHomol.Text:='';
   edCutoff.Text:='';
   end;
end;

procedure TfrmSelect.edLengthExit(Sender: TObject);
begin
if edlength.text<>'' then
   updatelength(strtoint(edlength.text));
end;

procedure TfrmSelect.edLengthKeyPress(Sender: TObject; var Key: Char);
begin
if not (key in ['0'..'9',#13,#8]) then
   begin
   showmessage('Input numerical value!');
   key:=#0;
   exit;
   end;
if key=#13 then
   updatelength(strtoint(edlength.text));
end;

procedure TfrmSelect.edHomolChange(Sender: TObject);
begin
if edHomol.Focused then
   begin
   edLength.Text:='';
   edCutoff.Text:='';
   end;
end;

procedure TfrmSelect.edHomolExit(Sender: TObject);
begin
if edHomol.text<>'' then
   updatehomol(strtofloat(edHomol.text));
end;

procedure TfrmSelect.edHomolKeyPress(Sender: TObject; var Key: Char);
begin
if not (key in ['0'..'9',#13,'.',#8]) then
   begin
   showmessage('Input numerical value!');
   key:=#0;
   exit;
   end;
if key=#13 then
   updateHomol(strtofloat(edHomol.text));
end;

procedure TfrmSelect.edCutoffChange(Sender: TObject);
begin
if edCutOff.Focused then
   begin
   edLength.Text:='';
   edHomol.Text:='';
   end;
end;

procedure TfrmSelect.edCutoffExit(Sender: TObject);
begin
if edCutoff.text<>'' then
   updateCutOff(strtofloat(edCutoff.text));
end;

procedure TfrmSelect.edCutoffKeyPress(Sender: TObject; var Key: Char);
begin
if not (key in ['0'..'9',#13,'.',#8]) then
   begin
   showmessage('Input numerical value!');
   key:=#0;
   exit;
   end;
if key=#13 then
   updateCutOff(strtofloat(edCutoff.text));
end;

procedure TfrmSelect.edMatchKeyPress(Sender: TObject; var Key: Char);
var i,w1:integer;
begin
if key=#13 then
   begin
   with frmMain do
   for i:=0 to lv.items.count-1 do
       if lv.items[i].subitems.count>=3 then
          for w1:=0 to 2 do
              begin
              if pos(uppercase(edMatch.text),uppercase(lv.items[i].subitems.strings[w1]))<>0 then
                 lv.items[i].checked:=true;
              if pos(uppercase(edNoMatch.text),uppercase(lv.items[i].subitems.strings[w1]))<>0 then
                 lv.items[i].checked:=false;
              end;
    compte;
    end;
end;

procedure TfrmSelect.btnCloseClick(Sender: TObject);
begin
if edLength.text<>'' then
   updatelength(strtoint(edLength.text));
if edHomol.text<>'' then
   updatehomol(strtofloat(edHomol.text));
if edCutOff.text<>'' then
   updateCutOff(strtofloat(edCutoff.text));
close;
end;

end.
